@@ -132,7 +132,7 @@ function (x, constraint = "N", lambda = 1, dummies = dummies,
 # linear function with "knots" at the observed x_i points.  Additive models can consist
 # of several components of this form plus partial linear and triogram components.
 # To resolve the identifiability problem we delete the first column of the qss design
-# components.  On return F contains the fidelity portion of the design, A the penalty
+# components.  On return F contains the fidelity portion of the design, A is the penalty
 # contribution of the design, R the constraint portion, and r the rhs of the constraints.
 #
 # Constraints are specified by the constraint argument:
@@ -517,7 +517,8 @@ function (object, newdata, interval = "none",  level = 0.95, ...)
         m <- 0
     }
     if(requireNamespace("MatrixModels") && requireNamespace("Matrix"))
-        X <- as(MatrixModels::model.Matrix(PLTerms, data = nd, sparse = TRUE),"matrix.csr")
+        X <- as(MatrixModels::model.Matrix(PLTerms, data = nd, 
+		  contrasts = contrasts, sparse = TRUE),"matrix.csr")
     else
         X <- model.matrix(PLTerms, data = nd)
     p <- ncol(X)
@@ -684,7 +685,7 @@ resid.rqss <- function(object, ...) object$resid[1:object$n]
     process <- (tau < 0 || tau > 1)
     Y <- model.extract(m, "response")
     if(requireNamespace("MatrixModels") && requireNamespace("Matrix")){
-         X <- MatrixModels::model.Matrix(Terms, m, contrasts, sparse = TRUE)
+         X <- MatrixModels::model.Matrix(Terms, m, contrasts.arg = contrasts, sparse = TRUE)
          vnames <- dimnames(X)[[2]]
          X <- as(X ,"matrix.csr")
          }
@@ -861,10 +862,7 @@ resid.rqss <- function(object, ...) object$resid[1:object$n]
     n <- length(resid) - nrL - nrA[m]
     uhat <- resid[1:n]
     h <- bandwidth.rq(tau, n, hs = TRUE)
-    if(tau + h > 1)
-       stop("tau + h > 1:  error in summary.rq")
-    if(tau - h < 0)
-       stop("tau - h < 0:  error in summary.rq")
+    while((tau - h < 0) || (tau + h > 1)) h <- h/2
     h <- (qnorm(tau + h) - qnorm(tau - h)) * max(ztol,min(sqrt(var(uhat)),
         (quantile(uhat, 0.75) - quantile(uhat, 0.25))/1.34))
     f <- c(dnorm(uhat/h)/h,rep(1, length(resid) - n))
